Documentation
¶
Overview ¶
Package ignition aggregates all Ignition flavors into a single package to be consumed by the bootstrap provider by exposing an API similar to 'internal/cloudinit' package.
Index ¶
Constants ¶
This section is empty.
Variables ¶
This section is empty.
Functions ¶
func NewInitControlPlane ¶
func NewInitControlPlane(input *ControlPlaneInput) ([]byte, string, error)
NewInitControlPlane returns Ignition configuration for bootstrapping new cluster.
func NewJoinControlPlane ¶
func NewJoinControlPlane(input *ControlPlaneJoinInput) ([]byte, string, error)
NewJoinControlPlane returns Ignition configuration for new controlplane node joining the cluster.
Types ¶
type ControlPlaneInput ¶
type ControlPlaneInput struct {
*cloudinit.ControlPlaneInput
Ignition *bootstrapv1.IgnitionSpec
}
ControlPlaneInput defines the context to generate a controlplane instance user data.
type ControlPlaneJoinInput ¶
type ControlPlaneJoinInput struct {
*cloudinit.ControlPlaneJoinInput
Ignition *bootstrapv1.IgnitionSpec
}
ControlPlaneJoinInput defines context to generate controlplane instance user data for control plane node join.
type NodeInput ¶
type NodeInput struct {
*cloudinit.NodeInput
Ignition *bootstrapv1.IgnitionSpec
}
NodeInput defines the context to generate a node user data.
Click to show internal directories.
Click to hide internal directories.